/*
    jLensInfo - Example for Nikon

    This file is part of jLensInfo by  
    @author Philipp Hoehne <http://digicam4.me> 

    Usage: 
        java -cp jLensInfo.jar com.phoehne.exif.lensinfo.nikon.Example <image>

        e.g.:
            Windows
            java -cp jLensInfo.jar com.phoehne.exif.lensinfo.nikon.Example samples\nikon.jpg

            OSX/ Linux:
            java -cp jLensInfo.jar com.phoehne.exif.lensinfo.nikon.Example samples/nikon.jpg

    License:

    jLensInfo  is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    jLensInfo is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with jLensInfo.  If not, see <http://www.gnu.org/licenses/>.
*/

package com.phoehne.exif.lensinfo.nikon;

import com.drew.imaging.ImageMetadataReader;
import com.drew.imaging.ImageProcessingException;
import com.drew.metadata.Directory;
import com.drew.metadata.Metadata;
import com.drew.metadata.exif.ExifIFD0Directory;
import com.drew.metadata.exif.NikonType2MakernoteDirectory;
import java.io.File;

public class Example {

    public static void main(String[] args) {
        
        Directory ExifIFD0Dir = new ExifIFD0Directory();
        Directory NikonType2Dir = new NikonType2MakernoteDirectory();
        Directory workDir;
        Metadata metadata;
        File f = null;
        String maker = "unknown maker";
        String model = "unknown model";
        byte[] lensType = null;
        byte[] lensData = null;
        int serialNumber = 0;
        int shutterCount = 0;
        LensNamesForNikon nikonLensNames = null;
        
        if(args.length == 1) { 
            f = new File(args[0]);
        }
        else {
            System.out.println("Wrong number of parameters!\nUsage: java -cp jLensInfo.jar com.phoehne.exif.lensinfo.nikon.Example <image file> ");
            System.exit(-1);
        }
        
        try {
            
                nikonLensNames = new LensNamesForNikon();
                
                metadata = ImageMetadataReader.readMetadata(f);

                // Get Maker and Model
                if (metadata.containsDirectory(ExifIFD0Dir.getClass())) {
                    workDir = metadata.getDirectory(ExifIFD0Dir.getClass());
                    if(workDir.containsTag(ExifIFD0Directory.TAG_MAKE)) {
                        maker = workDir.getString(ExifIFD0Directory.TAG_MAKE);
                        if(!maker.toUpperCase().contains("NIKON")) {
                            System.out.println("The metadata info in the provided file is corrupt or not a Nikon file\nCamera Maker found was: " + maker);
                            System.exit(-1);
                        }
                    }    
                    if(workDir.containsTag(ExifIFD0Directory.TAG_MODEL)) {
                        model = workDir.getString(ExifIFD0Directory.TAG_MODEL);
                    } 
                    else {  System.out.println("Not able to get the Camera Model name"); // We need this for special treatment as for the D50
                            System.exit(-1);                    
                    }
                }
                if (metadata.containsDirectory(NikonType2Dir.getClass())) {
                    workDir = metadata.getDirectory(NikonType2Dir.getClass());
                    if(workDir.containsTag(NikonType2MakernoteDirectory.TAG_NIKON_TYPE2_LENS_TYPE)) {
                        lensType = workDir.getByteArray(NikonType2MakernoteDirectory.TAG_NIKON_TYPE2_LENS_TYPE);
                    }
                    if(workDir.containsTag(NikonType2MakernoteDirectory.TAG_NIKON_TYPE2_LENS_DATA)) {
                        lensData = workDir.getByteArray(NikonType2MakernoteDirectory.TAG_NIKON_TYPE2_LENS_DATA);
                    }

                    try {
                       serialNumber = Integer.parseInt(workDir.getString(NikonType2MakernoteDirectory.TAG_NIKON_TYPE2_CAMERA_SERIAL_NUMBER));
                    }
                    catch (Exception e) {
                        if (model.equals("NIKON D50")) {
                                serialNumber = 0x22;
                        } else {
                            serialNumber = 0x60;
                        } 
                    }
                    try {
                       shutterCount = workDir.getInt(167);
                    }
                    catch (Exception e) {
                            System.out.println("Not able to retrive the Shutter Count");
                            System.exit(-1);  
                    };                                 
                    
                    NikonLensNameExtractor myNikonLensNameExtractor = new NikonLensNameExtractor();
                    System.out.println(maker + " : " + model + " : " + myNikonLensNameExtractor.getName(lensData, lensType[0], shutterCount, serialNumber));
                }                   
        }
        catch (java.io.FileNotFoundException FNFE) {
            System.out.println("An error occured:\nCan't find the file: "+ f.getAbsolutePath());
        }
        
        catch (ImageProcessingException IMPE) {
            System.out.println("Image Processing Exception");
        }
        catch (Exception e) {
            System.out.println("An error occured:\n"+e.getLocalizedMessage());
        }
        
        
    }    
}


